==> owncloud_6.0.4~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/pt_PT.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "Contactos",
"Save" => "Guardar",
"Uploading..." => "A enviar...",
"Importing..." => "A importar...",
"Imported {count} of {total} contacts" => "Importado {contagem} de {totais} contactos",
"Imported {imported} contacts. {failed} failed." => "Importou {imported} contactos. Falharam {failed}.",
"An address book called {name} already exists" => "O livro de endereços {name} já existe",
"Failed adding address book: {error}" => "Não foi possível adicionar o livro de endereços: {error}",
"Failed loading address books: {error}" => "Não foi possível carregar o livro de endereços: {error}",
"Indexing contacts" => "A indexar os contactos",
"Unrecoverable error loading address books: {msg}" => "Erro irrecuperável enquanto tentava carregar os livros de endereço: {msg}",
"Error." => "Erro.",
"Add to..." => "Adicionar a...",
"Remove from..." => "Remover de...",
"Add group..." => "Adicionar grupo...",
"Invalid URL: \"{url}\"" => "URL inválido: \"{url}\"",
"There was an error opening a mail composer." => "Houve um erro a abrir o editor de e-mail.",
"Invalid email: \"{url}\"" => "Correio eletrónico inválido: \"{url}\"",
"Merge failed. Cannot find contact: {id}" => "Falhou a junção. Não se encontrou o contacto: {id}",
"Merge failed." => "Junção falhou.",
"Merge failed. Error saving contact." => "Junção falhou. Erro ao guardar contacto.",
"Select photo" => "Selecione uma fotografia",
"Network or server error. Please inform administrator." => "Erro de rede ou do servidor. Por favor, informe o administrador.",
"Error adding to group." => "Erro a adicionar ao grupo.",
"Error removing from group." => "Erro a remover do grupo.",
"Error setting {name} as favorite." => "Erro ao marcar {name} como favorito.",
"Merge contacts" => "Juntar contactos",
"Cancel" => "Cancelar",
"Add group" => "Adicionar grupo",
"OK" => "OK",
"Could not find contact: {id}" => "Não foi possível encontrar o contacto: {id}",
"No files selected for upload." => "Nenhum ficheiro selecionado para enviar.",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "O tamanho do ficheiro que está a tentar carregar ultrapassa o limite máximo definido para ficheiros no servidor.",
"Edit profile picture" => "Editar a fotografia de perfil.",
"Crop photo" => "Cortar foto",
"Is this correct?" => "Isto está correcto?",
"# groups" => "# grupos",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Alguns contactos forma marcados para apagar, mas ainda não foram apagados. Por favor espere que ele sejam apagados.",
"Click to undo deletion of {num} contacts" => "Clique para desfazer a eliminar de {num} contactos",
"Add" => "Adicionar",
"Contact is already in this group." => "O contacto já está neste grupo.",
"Contacts are already in this group." => "Os contactos já estão neste grupo",
"Couldn't get contact list." => "Não foi possível ler a lista de contactos",
"Contact is not in this group." => "O contacto não está neste grupo",
"Contacts are not in this group." => "Os contactos não estão neste grupo",
"Failed renaming group: {error}" => "Erro ao tentar renomear o grupo: {error}",
"A group named {group} already exists" => "Um grupo com o nome {group} já existe",
"You can drag groups to\narrange them as you like." => "Pode arrastar grupos para\ncolocá-los como desejar.",
"Failed adding group: {error}" => "Erro ao adicionar o grupo: {error}",
"All" => "Todos",
"Favorites" => "Favoritos",
"Shared by {owner}" => "Partilhado por {owner}",
"Not grouped" => "Não agrupados",
"Failed loading groups: {error}" => "Erro ao carregar grupos: {error}",
"Please choose the addressbook" => "Por favor seleccione o livro de endereços",
"Import" => "Importar",
"Import done" => "Importação terminada",
"Close" => "Fechar",
"Error" => "Erro",
"Displayname cannot be empty." => "Displayname não pode ser vazio",
"Show CardDav link" => "Mostrar ligação CardDAV",
"Show read-only VCF link" => "Mostrar ligações VCF só de leitura",
"Download" => "Transferir",
"Edit" => "Editar",
"Delete" => "Eliminar",
"More..." => "Mais...",
"Less..." => "Menos...",
"Server error! Please inform system administator" => "Erro no servidor! Por favor informe o Administrador do Sistema",
"Failed loading photo: {error}" => "Erro ao carregar fotografia: {error}",
"You do not have permissions to see this contacts" => "Não tem permissões para ver este contacto",
"Contact not found" => "Contacto não encontrado",
"You do not have permissions to see these contacts" => "Não tem permissões para ver estes contactos",
"You do not have permissions add contacts to the address book" => "Não tem permissões para adicionar contactos ao livro de endereços",
"The backend for this address book does not support adding contacts" => "O bastidor para este livro de endereços não suporta o adicionar de contactos",
"You do not have permissions to delete this contact" => "Não tem permissões para apagar este contacto.",
"The backend for this address book does not support deleting contacts" => "O bastidor para este livro de endereços não suporta o apagar de contactos",
"Unknown error" => "Erro Desconhecido",
"The backend for this address book does not support updating" => "O suporte deste  livro de endereços não suporta atualizações",
"You don't have permissions to update the address book." => "Não tem permissões para atualizar este livro de endereços",
"You don't have permissions to delete the address book." => "Não tem permissões para apagar este livro de endereços.",
"Address book not found" => "Nenhum livro de endereços encontrado.",
"You do not have permissions to see this contact" => "Não tem permissões para ver este contacto",
"You do not have permissions to update this contact" => "Não tem permissões para atualizar este contacto",
"The backend for this contact does not support updating it" => "O suporte deste contacto não suporta atualizações",
"This backend not support adding contacts" => "O suporte não aceita contactos adicionais",
"Property not found" => "Propriedade não encontrada",
" Missing IM parameter for: " => "Falta o parâmetro de mensagens instantâneas para:",
"Unknown IM: " => "Mensagens instantâneas desconhecida (IM)",
"{name}'s Birthday" => "Aniversário de {name}",
"Error creating address book" => "Erro ao criar livro de endereços",
"Error updating address book" => "Erro ao atualizar o livro de endereços",
"Error deleting address book" => "Erro ao apagar o livro de endereços",
"Error creating contact." => "Erro a criar contacto.",
"Error deleting contact." => "Erro ao apagar contacto.",
"Error retrieving contact." => "Erro a guardar contacto.",
"Error saving contact." => "Erro a guardar o contacto.",
"Error removing contact from other address book." => "Erro ao remover o contacto do livro de endereços.",
"Couldn't find contact." => "Não é possível encontrar o contacto.",
"Error merging into contact." => "Erro ao adicionar detalhes ao contacto.",
"Error saving contact to backend." => "Erro ao guardar o contacto no suporte.",
"Property name is not set." => "O nome da propriedade não está definido,",
"Information about vCard is incorrect. Please reload the page." => "A informação sobre o vCard está incorreta. Por favor recarregue a página",
"Error updating contact" => "Erro ao actualizar o contacto",
"No file was uploaded. Unknown error" => "Nenhum ficheiro foi carregado. Erro desconhecido",
"There is no error, the file uploaded with success" => "Não ocorreram erros, o ficheiro foi submetido com sucesso",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "O ficheiro enviado excede a directiva upload_max_filesize no php. ini\n ",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "O tamanho do ficheiro carregado ultrapassa o valor MAX_FILE_SIZE definido no formulário HTML",
"The uploaded file was only partially uploaded" => "O ficheiro selecionado  foi apenas carregado parcialmente",
"No file was uploaded" => "Nenhum ficheiro foi submetido",
"Missing a temporary folder" => "Está a faltar a pasta temporária",
"Couldn't load temporary image: " => "Não é possível carregar a imagem temporária: ",
"Couldn't save temporary image: " => "Não foi possível guardar a imagem temporária: ",
"No photo path was submitted." => "Nenhum caminho da foto definido.",
"File doesn't exist:" => "Ficheiro não existe:",
"Error loading image." => "Erro a carregar a imagem.",
"Error creating temporary image" => "Erro a criar a imagem temporária",
"Error cropping image" => "Erro a recorar a imagem",
"Error resizing image" => "Erro a redimensionar a imagem",
"Error getting PHOTO property." => "Erro a obter a propriedade Foto",
"No group name given." => "Grupo sem nome.",
"Error adding group." => "Erro a adicionar o grupo",
"No group name to rename from given." => "Não foi dado um novo nome ao grupo recebido.",
"No group name to rename to given." => "Não foi dado um novo nome ao grupo dado.",
"Error renaming group." => "Erro ao renomear grupo.",
"Group ID missing from request." => "Falta o ID do grupo no pedido",
"Group name missing from request." => "Nome de grupo em falta.",
"Contact ID missing from request." => "Falta o ID do contacto no pedido",
"Failed to write to disk" => "Falhou a escrita no disco",
"Not enough storage available" => "Não há espaço suficiente em disco",
"Error uploading contacts to storage." => "Erro a carregar os contactos para o armazenamento.",
"No contacts found in: " => "Nenhum contacto encontrado em:",
"Could not set preference: " => "Não foi possível definir as preferências :",
"Contact" => "Contacto",
"Other" => "Outro",
"HomePage" => "Página Inicial",
"Jabber" => "Jabber",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"Work" => "Emprego",
"Home" => "Casa",
"Mobile" => "Telemóvel",
"Text" => "Texto",
"Voice" => "Voz",
"Message" => "Mensagem",
"Fax" => "Fax",
"Video" => "Vídeo",
"Pager" => "Pager",
"Internet" => "Internet",
"Friends" => "Amigos",
"Family" => "Familia",
"New Contact" => "Novo Contacto",
"Group name" => "Grupo",
"New Group" => "Novo Grupo",
"Address books" => "Livro de endereços",
"Display name" => "Mostrar nome",
"Add Address Book" => "Adicionar Livro de Endereços",
"Select file..." => "Seleccionar ficheiro...",
"(De-)select all" => "(Des)seleccionar todos",
"Groups" => "Grupos",
"Favorite" => "Favorito",
"Keyboard shortcuts" => "Atalhos de teclado",
"Navigation" => "Navegação",
"Next contact in list" => "Próximo contacto na lista",
"Previous contact in list" => "Contacto anterior na lista",
"Expand/collapse current addressbook" => "Expandir/encolher o livro de endereços atual",
"Next addressbook" => "Próximo livro de endereços",
"Previous addressbook" => "Livro de endereços anterior",
"Actions" => "Ações",
"Refresh contacts list" => "Recarregar lista de contactos",
"Add new contact" => "Adicionar novo contacto",
"Add new addressbook" => "Adicionar novo Livro de endereços",
"Delete current contact" => "Apagar o contacto atual",
"Add contact" => "Adicionar contacto",
"Delete group" => "Eliminar grupo",
"Compose mail" => "Escrever e-mail.",
"Delete current photo" => "Eliminar a foto actual",
"Edit current photo" => "Editar a foto actual",
"Upload new photo" => "Carregar nova foto",
"Select photo from ownCloud" => "Selecionar uma foto da ownCloud",
"Name" => "Nome",
"First name" => "Primeiro Nome",
"Additional names" => "Nomes adicionais",
"Last name" => "Ultimo Nome",
"Select groups" => "Seleccionar grupos",
"Nickname" => "Alcunha",
"Enter nickname" => "Introduza alcunha",
"Title" => "Título ",
"Enter title" => "Introduza o título",
"Organization" => "Organização",
"Birthday" => "Aniversário",
"Notes go here..." => "As notas ficam aqui:",
"Export as VCF" => "Exportar como VCF",
"Phone" => "Telefone",
"Email" => "Email",
"Instant Messaging" => "Mensagens Instantâneas",
"Address" => "Endereço",
"Note" => "Nota",
"Web site" => "Página web",
"Delete contact" => "Apagar contacto",
"Preferred" => "Preferido",
"Please specify a valid email address." => "Por favor indique um endereço de correio válido",
"someone@example.com" => "alguem@exemplo.com",
"Mail to address" => "Enviar correio para o endereço",
"Delete email address" => "Eliminar o endereço de correio",
"Enter phone number" => "Insira o número de telefone",
"Delete phone number" => "Eliminar o número de telefone",
"Go to web site" => "Ir para página web",
"Delete URL" => "Eliminar Endereço (URL)",
"View on map" => "Ver no mapa",
"Delete address" => "Eliminar endereço",
"1600 Pennsylvania Avenue, NW" => "1600 Pennsylvania Avenue, NW",
"Street address" => "Endereço da Rua",
"20500" => "20500",
"Postal code" => "Código Postal",
"Washington, DC" => "Washington, DC",
"City" => "Cidade",
"USA" => "EUA",
"Country" => "País",
"Instant Messenger" => "Mensageiro instantâneo",
"Delete IM" => "Apagar mensageiro instantâneo (IM)",
"Active" => "Activo",
"Share" => "Partilhar",
"Export" => "Exportar",
"CardDAV syncing addresses" => "CardDAV a sincronizar endereços",
"more info" => "mais informação",
"Primary address (Kontact et al)" => "Endereço principal (Kontact et al.)",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Livros de endereços",
"New Address Book" => "Novo livro de endereços",
"Description" => "Descrição"
);

==> owncloud_7.0.0~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/contacts/l10n/pt_PT.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "Contactos",
"Add new LDAP Addressbook" => "Adicionar novo Livro de endereços LDAP",
"Ok" => "Ok",
"Cancel" => "Cancelar",
"Save" => "Guardar",
"Edit Addressbook" => "Editar livro de endereços",
"Starting file import" => "A iniciar importação de ficheiro",
"Format selected: {format}" => "Format selected: {format}",
"Automatic format detection" => "Deteção automática do formato",
"Processing {count}/{total} cards" => "A processar {count}/{total} cartões",
"Total:{total}, Success:{imported}, Errors:{failed}" => "Total:{total}, Com êxito:{imported}, Erros:{failed}",
"An address book called {name} already exists" => "O livro de endereços {name} já existe",
"Failed adding address book: {error}" => "Não foi possível adicionar o livro de endereços: {error}",
"Failed loading address books: {error}" => "Não foi possível carregar o livro de endereços: {error}",
"Server error! Please inform system administator" => "Erro no servidor! Por favor informe o Administrador do Sistema",
"Indexing contacts" => "A indexar os contactos",
"Unrecoverable error loading address books: {msg}" => "Erro irrecuperável enquanto tentava carregar os livros de endereço: {msg}",
"Error." => "Erro.",
"Add to..." => "Adicionar a...",
"Remove from..." => "Remover de...",
"Add group..." => "Adicionar grupo...",
"Invalid URL: \"{url}\"" => "URL inválido: \"{url}\"",
"Invalid email: \"{url}\"" => "Correio eletrónico inválido: \"{url}\"",
"Merge failed. Cannot find contact: {id}" => "Falhou a junção. Não se encontrou o contacto: {id}",
"Merge failed." => "Junção falhou.",
"Merge failed. Error saving contact." => "Junção falhou. Erro ao guardar contacto.",
"Select photo" => "Selecione uma fotografia",
"Network or server error. Please inform administrator." => "Erro de rede ou do servidor. Por favor, informe o administrador.",
"Only images can be used as contact photos" => "Apenas imagens podem ser usadas para as fotos dos contatos",
"The size of \"{filename}\" exceeds the maximum allowed {size}" => "O tamanho do ficheiro \"{filename}\" excede o máximo permitido {tamanho}",
"Error adding to group." => "Erro a adicionar ao grupo.",
"Error removing from group." => "Erro a remover do grupo.",
"You have selected over 300 contacts.\nThis will most likely fail! Click here to try anyway." => "Você selecionou mais de 300 contactos.\nIsto irá falhar de certeza! Clique aqui para tentar na mesma.",
"Error setting {name} as favorite." => "Erro ao marcar {name} como favorito.",
"Merge contacts" => "Juntar contactos",
"Add group" => "Adicionar grupo",
"OK" => "OK",
"Could not find contact: {id}" => "Não foi possível encontrar o contacto: {id}",
"Edit profile picture" => "Editar a fotografia de perfil.",
"Crop photo" => "Cortar foto",
"Error parsing date: {date}" => "Erro ao processar data: {date}",
"# groups" => "# grupos",
"Error parsing birthday {bday}" => "Erro ao analisar aniversário {bday}",
"The backend does not support multi-byte characters." => "A base de dados não permite a programação em todas as codificações",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Alguns contactos forma marcados para apagar, mas ainda não foram apagados. Por favor espere que ele sejam apagados.",
"Click to undo deletion of {num} contacts" => "Clique para desfazer a eliminar de {num} contactos",
"Cancelled deletion of {num} contacts" => "Cancelada a eliminação de {num} contactos",
"Add" => "Adicionar",
"Contact is already in this group." => "O contacto já está neste grupo.",
"Contacts are already in this group." => "Os contactos já estão neste grupo",
"Couldn't get contact list." => "Não foi possível ler a lista de contactos",
"Contact is not in this group." => "O contacto não está neste grupo",
"Contacts are not in this group." => "Os contactos não estão neste grupo",
"A group named \"{group}\" already exists" => "Um grupo chamado \"{group}\" já existe",
"Failed renaming group: {error}" => "Erro ao tentar renomear o grupo: {error}",
"You can drag groups to\narrange them as you like." => "Pode arrastar grupos para\ncolocá-los como desejar.",
"Failed adding group: {error}" => "Erro ao adicionar o grupo: {error}",
"All" => "Todos",
"Favorites" => "Favoritos",
"Shared by {owner}" => "Partilhado por {owner}",
"Not grouped" => "Não agrupados",
"Failed loading groups: {error}" => "Erro ao carregar grupos: {error}",
"Please choose the addressbook" => "Por favor seleccione o livro de endereços",
"Import into..." => "Importar para...",
"Error loading import template" => "Erro ao importar o template",
"Import contacts" => "Importar contactos",
"Import" => "Importar",
"Importing..." => "A importar...",
"Import done" => "Importação terminada",
"Close" => "Fechar",
"Error, missing parameters: " => "Erro, parâmetros em falta:",
"Failed loading photo: {error}" => "Erro ao carregar fotografia: {error}",
"You do not have permissions to see this contact" => "Não tem permissões para ver este contacto",
"Contact not found" => "Contacto não encontrado",
"You do not have permissions to see these contacts" => "Não tem permissões para ver estes contactos",
"You do not have permissions add contacts to the address book" => "Não tem permissões para adicionar contactos ao livro de endereços",
"The backend for this address book does not support adding contacts" => "O bastidor para este livro de endereços não suporta o adicionar de contactos",
"You do not have permissions to delete this contact" => "Não tem permissões para apagar este contacto.",
"The backend for this address book does not support deleting contacts" => "O bastidor para este livro de endereços não suporta o apagar de contactos",
"Unknown error" => "Erro Desconhecido",
"Access denied" => "Acesso negado",
"The backend for this address book does not support updating" => "O suporte deste  livro de endereços não suporta atualizações",
"You don't have permissions to delete the address book." => "Não tem permissões para apagar este livro de endereços.",
"Address book not found" => "Nenhum livro de endereços encontrado.",
"You do not have permissions to update this contact" => "Não tem permissões para atualizar este contacto",
"The backend for this contact does not support updating it" => "O suporte deste contacto não suporta atualizações",
"This backend does not support adding contacts" => "Backend não suporta contatos adicionais",
"Property not found" => "Propriedade não encontrada",
" Missing IM parameter for: " => "Falta o parâmetro de mensagens instantâneas para:",
"Unknown IM: " => "Mensagens instantâneas desconhecida (IM)",
"{name}'s Birthday" => "Aniversário de {name}",
"Error creating address book" => "Erro ao criar livro de endereços",
"The \"%s\" backend does not support deleting address books" => "O suporte \"%s\" não permite eliminar livros de endereços",
"You do not have permissions to delete the \"%s\" address book" => "Não tem permissões para eliminar o \"%s\" livro de endereços",
"Error deleting address book" => "Erro ao apagar o livro de endereços",
"Error creating contact." => "Erro a criar contacto.",
"Error creating contact" => "Erro a criar o contacto",
"Error deleting contact" => "Erro a eliminar o contacto",
"Error retrieving contact" => "Erro a obter o contacto",
"Error saving contact" => "Erro a guardar o contacto",
"Error removing contact from other address book." => "Erro ao remover o contacto do livro de endereços.",
"Error getting moved contact" => "Erro a obter o contacto movido",
"Couldn't find contact." => "Não é possível encontrar o contacto.",
"No contact data in request." => "Não há dados de contacto no pedido.",
"Error merging into contact." => "Erro ao adicionar detalhes ao contacto.",
"Error saving contact to backend." => "Erro ao guardar o contacto no suporte.",
"Property name is not set." => "O nome da propriedade não está definido,",
"Property checksum is not set." => "A propriedade checksum não está configurada.",
"Information about vCard is incorrect. Please reload the page." => "A informação sobre o vCard está incorreta. Por favor recarregue a página",
"Error updating contact" => "Erro ao actualizar o contacto",
"Error saving contact to backend" => "Erro ao guardar o contacto no suporte",
"Error getting user photo" => "Erro a obter a fotografia do utilizador",
"No photo path was submitted." => "Nenhum caminho da foto definido.",
"Error loading image from cache" => "Erro a carregar a imagem da cache",
"Error getting PHOTO property." => "Erro a obter a propriedade Foto",
"Error saving contact." => "Erro a guardar o contacto.",
"No group name given." => "Grupo sem nome.",
"Error adding group." => "Erro a adicionar o grupo",
"No group name to rename from given." => "Não foi dado um novo nome ao grupo recebido.",
"No group name to rename to given." => "Não foi dado um novo nome ao grupo dado.",
"Error renaming group." => "Erro ao renomear grupo.",
"Group ID missing from request." => "Falta o ID do grupo no pedido",
"Group name missing from request." => "Nome de grupo em falta.",
"Contact ID missing from request." => "Falta o ID do contacto no pedido",
"No file was uploaded. Unknown error" => "Nenhum ficheiro foi carregado. Erro desconhecido",
"There is no error, the file uploaded with success" => "Não ocorreram erros, o ficheiro foi submetido com sucesso",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "O ficheiro enviado excede a directiva upload_max_filesize no php. ini\n ",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "O tamanho do ficheiro carregado ultrapassa o valor MAX_FILE_SIZE definido no formulário HTML",
"The uploaded file was only partially uploaded" => "O ficheiro selecionado  foi apenas carregado parcialmente",
"No file was uploaded" => "Nenhum ficheiro foi submetido",
"Missing a temporary folder" => "Está a faltar a pasta temporária",
"Failed to write to disk" => "Falhou a escrita no disco",
"Not enough storage available" => "Não há espaço suficiente em disco",
"Attempt to upload blacklisted file:" => "Tentativa de envio de ficheiro bloqueado:",
"Error uploading contacts to storage." => "Erro a carregar os contactos para o armazenamento.",
"Error moving file to imports folder." => "Erro ao mover ficheiro para a pasta de importação.",
"You do not have permissions to import into this address book." => "Não tem permissões para importar para este livro de endereços.",
"File name missing from request." => "O nome do ficheiro está em falta.",
"Progress key missing from request." => "Chave de progresso em falta no pedido.",
"Attempt to access blacklisted file:" => "Tentativa de acesso a ficheiro bloqueado:",
"No key is given." => "A chave não foi fornecida.",
"No value is given." => "Não foi fornecido qualquer valor.",
"Could not set preference: " => "Não foi possível definir as preferências :",
"Contact" => "Contacto",
"Other" => "Outro",
"HomePage" => "Página Inicial",
"Jabber" => "Jabber",
"Internet call" => "Chamada através da Internet",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"ownCloud" => "ownCloud",
"Work" => "Emprego",
"Home" => "Casa",
"Mobile" => "Telemóvel",
"Text" => "Texto",
"Voice" => "Voz",
"Message" => "Mensagem",
"Fax" => "Fax",
"Video" => "Vídeo",
"Pager" => "Pager",
"Internet" => "Internet",
"Friends" => "Amigos",
"Family" => "Familia",
"Enable LDAP Backend" => "Activar LDAP Backend",
"Enable LDAP backend for the contacts application" => "Activar LDAP backend para a aplicação de contactos ",
"Warning: LDAP Backend is in beta mode, use with precautions" => "Atenção: LDAP Backend em modo beta, usar com cuidado",
"New contact" => "Novo contacto",
"Group name" => "Grupo",
"New group" => "Novo grupo",
"Address books" => "Livro de endereços",
"Display name" => "Mostrar nome",
"Add Address Book" => "Adicionar Livro de Endereços",
"Add LDAP Address Book" => "Adicionar Livro de Endereços LDAP",
"Automatic format" => "Formato automático",
"Select file..." => "Seleccionar ficheiro...",
"(De-)select all" => "(Des)seleccionar todos",
"Sort order" => "Ordem da ordenação",
"First- Lastname" => "Primeiro- Último Nome",
"Last-, Firstname" => "Último-, Primeiro Nome",
"Delete" => "Eliminar",
"Groups" => "Grupos",
"Download" => "Transferir",
"Merge" => "Fundir",
"Email" => "Email",
"Phone" => "Telefone",
"Address" => "Endereço",
"Group" => "Grupo",
"Keyboard shortcuts" => "Atalhos de teclado",
"Navigation" => "Navegação",
"Next contact in list" => "Próximo contacto na lista",
"Previous contact in list" => "Contacto anterior na lista",
"Expand/collapse current addressbook" => "Expandir/encolher o livro de endereços atual",
"Next addressbook" => "Próximo livro de endereços",
"Previous addressbook" => "Livro de endereços anterior",
"Actions" => "Ações",
"Refresh contacts list" => "Recarregar lista de contactos",
"Add new contact" => "Adicionar novo contacto",
"Add new addressbook" => "Adicionar novo Livro de endereços",
"Delete current contact" => "Apagar o contacto atual",
"You have no contacts in your address book or your address book is disabled." => "Não tem nenhuns contatos no seu livro de endereços ou o seu livro de endereços está desativo",
"Add a new contact or import existing contacts from a VCF file." => "Adicione um novo contato ou importe através de um ficheiro VCF ",
"Which contact should the data be merged into?" => "Quais os dados dos contactos que devem ser juntados?",
"Delete the other(s) after successful merge?" => "Eliminar o(s) outro(s) após finalizar com sucesso a junção?",
"Compose mail" => "Escrever e-mail.",
"Delete current photo" => "Eliminar a foto actual",
"Edit current photo" => "Editar a foto actual",
"Upload new photo" => "Carregar nova foto",
"Select photo from Files" => "Seleccione a foto a partir dos ficheiros",
"Favorite" => "Favorito",
"Name" => "Nome",
"First name" => "Primeiro Nome",
"Additional names" => "Nomes adicionais",
"Last name" => "Ultimo Nome",
"Address book" => "Livro de endereços",
"Nickname" => "Alcunha",
"Title" => "Título ",
"Organization" => "Organização",
"Birthday" => "Aniversário",
"Website" => "Site da Internet",
"Instant messaging" => "Mensagens Instantâneas",
"Notes go here..." => "As notas ficam aqui:",
"Add field..." => "Adicionar campo...",
"Instant Messaging" => "Mensagens Instantâneas",
"Note" => "Nota",
"Web site" => "Página web",
"Preferred" => "Preferido",
"Please specify a valid email address." => "Por favor indique um endereço de correio válido",
"someone@example.com" => "alguem@exemplo.com",
"Mail to address" => "Enviar correio para o endereço",
"Delete email address" => "Eliminar o endereço de correio",
"Enter phone number" => "Insira o número de telefone",
"Go to web site" => "Ir para página web",
"View on map" => "Ver no mapa",
"Street address" => "Endereço da Rua",
"Postal code" => "Código Postal",
"City" => "Cidade",
"State or province" => "Distrito",
"Country" => "País",
"Instant Messenger" => "Mensageiro instantâneo",
"Active" => "Activo",
"Share" => "Partilhar",
"Export" => "Exportar",
"CardDAV link" => "Endereço CardDAV",
"Edit" => "Editar",
"Addressbook URI" => "Livro de endereços URI",
"URI" => "URI",
"Description" => "Descrição",
"LDAP URL" => "LDAP URL",
"Anonymous" => "Anónimos",
"Read-only" => "Apenas de leitura",
"Read-Only" => "Apenas de leitura",
"User" => "Utilizador",
"Password" => "Palavra-passe",
"Page size" => "Tamanho da página",
"Base DN for search" => "Base DN para pesquisa",
"Base DN" => "DN base",
"Search filter" => "Filtro de pesquisa",
"Filter" => "Filtro",
"Base DN for modification" => "Base DN para alteracão ",
"Base DN modification" => "Alteracão da Base DN",
"Connector" => "Conector",
"Connector value (Better use external editor and copy/paste)" => "Valor de ligação (Utilize um editor externo e copy/paste)",
"Copy from (Warning, replaces current custom value)" => "Copiar de (Aviso, substitua o actual valor configurado)"
);
